@@ -3,12 +3,10 @@
 #' Retrieve details on any publications that have been associated with the study
 #'
 #' @param study_id A character string of a valid MTBLS study id
-#' @return a `tibble` of study publicatons
+#' @return a `tibble` of study publications
 #' @export
 #' @examples
-#' \dontrun{
 #' get_study_pubs('MTBLS375')
-#' }
 
 get_study_pubs <- function(study_id)
 {
@@ -17,8 +15,7 @@ get_study_pubs <- function(study_id)
       paste0(getOption('BASE_URL'),
              '/studies/',
              study_id,
-             '/publications'),
-      httr::add_headers(user_token = getOption('MTBLS_API_KEY'))
+             '/publications')
     )
 
 
